<?php
// $Id: comment_publish.pages.inc,v 1.1.2.2.2.2 2010/10/13 14:56:40 elliottf Exp $

/**
 * @file
 *
 * Page callbacks for the comment_publish module.
 *
 * @author: Elliott Foster
 * @copyright: NewMBC 2010
 */

/**
 * Returns a form to (un)publish a comment.
 */
function comment_publish_publish_form($form, $form_state, $node, $comment) {

  $form['nid'] = array('#type' => 'value', '#value' => $node->nid);
  $form['cid'] = array('#type' => 'value', '#value' => $comment->cid);
  $form['action'] = array('#type' => 'value');

  if ($comment->status) {
    $action = 'unpublish';
    $form['action']['#value'] = 0;
  }
  else {
    $action = 'publish';
    $form['action']['#value'] = 1;
  }

  $dest = array('path' => 'node/' . $node->nid, 'fragment' => 'comment-' . $comment->cid);
  if (isset($_GET['destination'])) {
    $dest = $_GET['destination'];
  }

  $form = confirm_form(
    $form,
    t('Are you sure you want to @action this comment?', array('@action' => $action)),
    $dest,
    t(
      'Submitting this form will @action this comment, making it @visibility to users on the site.',
      array('@action' => $action, '@visibility' => ($comment->status ? 'available' : 'unavailable'))
    ),
    t('@action', array('@action' => ucwords($action)))
  );

  return $form;
}

function comment_publish_publish_form_submit($form, &$form_state) {
  $query = db_update('comment')
    ->fields(array('status' => $form_state['values']['action']))
    ->condition('cid', $form_state['values']['cid'], '=');
  if ($query->execute()) {
    drupal_set_message(t('The comment was @action successfully', array('@action' => ($form_state['values']['action'] ? 'unpublished' : 'published'))));
  }
  else {
    drupal_set_message(
      t('There was a problem @action the comment. Please try again later.', array('@action' => ($form_state['values']['action'] ? 'unpublishing' : 'publishing')))
    );
  }

  if (!isset($_GET['destination'])) {
    $form_state['redirect'] = 'node/' . $form_state['values']['nid'];
  }
}

/**
 * (un)publishes a comment using AJAX.
 */
function comment_publish_js($node, $comment, $format, $reverse = 0) {
  global $user;

  $ostatus = $comment->status;
  if ($comment->status) {
    $action = t('unpublished');
    $eaction = t('unpublishing');
    $comment->status = 0;
    $foutput = t('publish');
    $ofoutput = t('unpublish');
    switch ($format) {
      case COMMENT_PUBLISH_PUBLISHED_UNPUBLISHED:
        $ofoutput = t('unpublished');
        $foutput = t('published');
        break; 
      case COMMENT_PUBLISH_YES_NO:
        $ofoutput = t('no');
        $foutput = t('yes');
        break;
    }
  }
  else {
    $action = t('published');
    $eaction = t('publishing');
    $comment->status = 1;
    $ofoutput = t('publish');
    $foutput = t('unpublish');
    switch ($format) {
      case COMMENT_PUBLISH_PUBLISHED_UNPUBLISHED:
        $ofoutput = t('published');
        $foutput = t('unpublished');
        break; 
      case COMMENT_PUBLISH_YES_NO:
        $ofoutput = t('yes');
        $foutput = t('no');
        break;
    }
  }

  if ($reverse) {
    $t = $ofoutput;
    $ofoutput = $foutput;
    $foutput = $t;
  }

  $query = db_update('comment')
    ->fields(array('status' => $comment->status))
    ->condition('cid', $comment->cid, '=');
  $success = $query->execute();
  if ($success) {
    watchdog('comment_publish', '@name @action comment @cid', array('@name' => $user->name, '@action' => $action, '@cid' => $comment->cid));
    return drupal_json_output(array('status' => $success, 'data' => array('status' => $comment->status, 'format' => $foutput)));
  }
  else {
    // This shouldn't happen...
    watchdog('comment_publish', '@name had an aerror @action comment @cid', array('@name' => $user->name, '@action' => $eaction, '@cid' => $comment->cid), WATCHDOG_ERROR);
    return drupal_json_output(array('status' => $success, 'data' => array('status' => $ostatus, 'format' => $ofoutput)));
  }
}

